#[non_exhaustive]pub struct UpdateApiConfigRequest {
pub update_mask: Option<FieldMask>,
pub api_config: Option<ApiConfig>,
/* private fields */
}Expand description
Request message for ApiGatewayService.UpdateApiConfig
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Field mask is used to specify the fields to be overwritten in the ApiConfig resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
api_config: Option<ApiConfig>Required. API Config resource.
Implementations
Sourceimpl UpdateApiConfigRequest
impl UpdateApiConfigRequest
pub fn new() -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateApiConfigRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateApiConfigRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateApiConfigRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_api_config<T>(self, v: T) -> Self
pub fn set_api_config<T>(self, v: T) -> Self
Sets the value of api_config.
Example
ⓘ
use google_cloud_apigateway_v1::model::ApiConfig;
let x = UpdateApiConfigRequest::new().set_api_config(ApiConfig::default()/* use setters */);Sourcepub fn set_or_clear_api_config<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_api_config<T>(self, v: Option<T>) -> Self
Sets or clears the value of api_config.
Example
ⓘ
use google_cloud_apigateway_v1::model::ApiConfig;
let x = UpdateApiConfigRequest::new().set_or_clear_api_config(Some(ApiConfig::default()/* use setters */));
let x = UpdateApiConfigRequest::new().set_or_clear_api_config(None::<ApiConfig>);Trait Implementations
Sourceimpl Clone for UpdateApiConfigRequest
impl Clone for UpdateApiConfigRequest
Sourcefn clone(&self) -> UpdateApiConfigRequest
fn clone(&self) -> UpdateApiConfigRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateApiConfigRequest
impl Debug for UpdateApiConfigRequest
Sourceimpl Default for UpdateApiConfigRequest
impl Default for UpdateApiConfigRequest
Sourcefn default() -> UpdateApiConfigRequest
fn default() -> UpdateApiConfigRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for UpdateApiConfigRequest
impl Message for UpdateApiConfigRequest
Sourceimpl PartialEq for UpdateApiConfigRequest
impl PartialEq for UpdateApiConfigRequest
impl StructuralPartialEq for UpdateApiConfigRequest